@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.70';
+our $VERSION = '0.7001';
 
 use warnings;
 use strict;
@@ -12,6 +12,7 @@ use parent qw( Graph );
 
 use Carp qw( croak );
 use Readonly;
+
 Readonly my $WEIGHT => 'weight';
 
 
@@ -219,13 +220,13 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.70
+version 0.7001
 
 =head1 SYNOPSIS
 
  use Graph::Weighted;
 
- my $gw = Graph::Weighted->new();
+ my $gw = Graph::Weighted->new;
  $gw->populate(
     [ [ 0,1,2,0,0 ], # Vertex 0 with 2 edges of weight 3
       [ 1,0,3,0,0 ], #    "   1      2 "               4
@@ -234,44 +235,44 @@ version 0.70
       [ 0,0,0,0,0 ], #    "   4      0 "               0
     ]
  );
- for my $vertex (sort { $a <=> $b } $gw->vertices) {
-    warn sprintf "vertex: %s weight=%.2f\n",
+ for my $vertex ( sort { $a <=> $b } $gw->vertices ) {
+    printf "vertex: %s weight=%.2f\n",
         $vertex,
         $gw->get_cost($vertex);
-    for my $successor (sort { $a <=> $b } $gw->successors($vertex)) {
-        warn sprintf "\tedge to: %s weight=%.2f\n",
+    for my $successor ( sort { $a <=> $b } $gw->successors($vertex) ) {
+        printf "\tedge to: %s weight=%.2f\n",
             $successor,
-            $gw->get_cost([$vertex, $successor]);
+            $gw->get_cost( [ $vertex, $successor ] );
     }
  }
 
- my ($lightest, $heaviest) = $gw->vertex_span();
- ($lightest, $heaviest) = $gw->edge_span();
+ my ( $lightest, $heaviest ) = $gw->vertex_span;
+ ( $lightest, $heaviest ) = $gw->edge_span;
 
- my $weight = $gw->path_cost(\@vertices);
+ my $weight = $gw->path_cost( \@vertices );
 
  my $attr = 'probability';
- $gw = Graph::Weighted->new();
+ $gw = Graph::Weighted->new;
  $gw->populate(
     {
-        0 => { label => 'A', 1=>0.4, 3=>0.6 }, # Vertex A with 2 edges, weight 1
-        1 => { label => 'B', 0=>0.3, 2=>0.7 }, # "      B "    2 "
-        2 => { label => 'C', 0=>0.5, 2=>0.5 }, # "      C "    2 "
-        3 => { label => 'D', 0=>0.2, 1=>0.8 }, # "      D "    2 "
+        0 => { label => 'A', foo => 'a', 1=>0.4, 3=>0.6 },
+        1 => { label => 'B', foo => 'b', 0=>0.3, 2=>0.7 },
+        2 => { label => 'C', foo => 'c', 0=>0.5, 2=>0.5 },
+        3 => { label => 'D', foo => 'd', 0=>0.2, 1=>0.8 },
     },
     $attr
  );
- for my $vertex (sort { $a <=> $b } $gw->vertices) {
-    warn sprintf "%s vertex: %s %s=%.2f\n",
-        $gw->get_vertex_attribute($vertex, 'label'),
+ for my $vertex ( sort { $a <=> $b } $gw->vertices ) {
+    printf "%s vertex: %s %s=%.2f\n",
+        $gw->get_vertex_attribute( $vertex, 'label' ),
         $vertex,
         $attr,
-        $gw->get_cost($vertex, $attr);
-    for my $successor (sort { $a <=> $b } $gw->successors($vertex)) {
-        warn sprintf "\tedge to: %s %s=%.2f\n",
+        $gw->get_cost( $vertex, $attr );
+    for my $successor ( sort { $a <=> $b } $gw->successors($vertex) ) {
+        printf "\tedge to: %s %s=%.2f\n",
             $successor,
             $attr,
-            $gw->get_cost([$vertex, $successor], $attr);
+            $gw->get_cost( [ $vertex, $successor ], $attr );
     }
  }
 
@@ -305,13 +306,10 @@ Populate a graph with weighted nodes.
 The data can be an arrayref of numeric vectors, a C<Math::Matrix> object, a
 C<Math::MatrixReal> object, or a hashref of numeric edge values.
 
-Data given as a hash reference may also contain an optional node label, as shown
-in the SYNOPSIS.
+Data given as a hash reference may also contain multiple node labels.  Also, the
+keys need not be numeric, just unique.
 
-The optional edge C<attribute> argument is a string with the default "weight."
-
-Multiple attributes may be applied to a graph, thereby layering and increasing
-the overall dimension.
+The optional C<attribute> argument is a string with the default "weight."
 
 =head2 get_cost()
 
@@ -320,28 +318,29 @@ the overall dimension.
   $c = $gw->get_cost(\@edge);
   $c = $gw->get_cost(\@edge, $attribute);
 
-Return the named attribute value for the vertex or edge.
+Return the named attribute value for the vertex or edge.  If no attribute name
+is given, the string "weight" is used.
 
 =head2 vertex_span()
 
  ($lightest, $heaviest) = $gw->vertex_span();
  ($lightest, $heaviest) = $gw->vertex_span($attr);
 
-Return the lightest and heaviest vertices.
+Return the lightest and heaviest vertices as array references.
 
 =head2 edge_span()
 
  ($lightest, $heaviest) = $gw->edge_span();
  ($lightest, $heaviest) = $gw->edge_span($attr);
 
-Return the lightest to heaviest edges.
+Return the lightest to heaviest edges as array references.
 
 =head2 path_cost()
 
  $c = $gw->path_cost(\@vertices);
  $c = $gw->path_cost(\@vertices, $attr);
 
-Return the summed weight (or given cost attribute) of the path edges.
+Return the summed weight (or cost attribute) of the path edges.
 
 For the cost of the shortest path, please see C<path_length> under
 L<Graph/"All-Pairs Shortest Paths (APSP)">.
